
BC = 'bower_components/'

STATIC_APPS_MAP = {
    'jquery': {
        'bower': [
            'jquery#3.5.1',
            'jquery-form#4.3.0'
        ],
        'js': [
            BC + 'jquery/dist/jquery.js',
            BC + 'jquery-form/dist/jquery.form.min.js',
            'jquery/jquery.ba-bbq.js',
            'jquery/ajax-csrf.js',
            'modal.js'
        ]
    },
    'bootstrap': {
        'bower': 'bootstrap#3.3.7',
        'css': BC + 'bootstrap/dist/css/bootstrap.css',
        'js': BC + 'bootstrap/dist/js/bootstrap.js'
    },
    'jasny': {
        'bower': 'jasny-bootstrap#3.1.3',
        'css': BC + 'jasny-bootstrap/dist/css/jasny-bootstrap.css',
        'js': BC + 'jasny-bootstrap/dist/js/jasny-bootstrap.js'
    },
    'fa': {
        'bower': 'components-font-awesome#5.15.1',
        'css': BC + 'components-font-awesome/css/all.css'
    },
    'chosen': {
        'bower': 'chosen#1.8.7',
        'css': BC + 'chosen/chosen.css',
        'js': BC + 'chosen/chosen.jquery.js'
    },
    'fancybox': {
        'bower': 'fancybox#3.5.7',
        'css': BC + 'fancybox/dist/jquery.fancybox.css',
        'js': BC + 'fancybox/dist/jquery.fancybox.js'
    },
    'fancybox2': {
        'bower': 'fancybox#2.1.6',
        'css': BC + 'fancybox/source/jquery.fancybox.css',
        'js': BC + 'fancybox/source/jquery.fancybox.js'
    },
    'bootstrap-theme': {
        'css': BC + 'bootstrap/dist/css/bootstrap-theme.css'
    },
    'pgwslideshow': {
        'bower': 'pgwslideshow#2.0.2',
        'css': [
            BC + 'pgwslideshow/pgwslideshow.css',
            BC + 'pgwslideshow/pgwslideshow_light.css'
        ],
        'js': BC + 'pgwslideshow/pgwslideshow.js'
    },
    'owl': {
        'bower': 'owl.carousel#2.3.4',
        'css': BC + 'owl.carousel/dist/assets/owl.carousel.css',
        'js': BC + 'owl.carousel/dist/owl.carousel.js'
    },
    'autocomplete': {
        'bower': 'devbridge-autocomplete#1.4.11',
        'js': (
            BC + 'devbridge-autocomplete/'
            'dist/jquery.autocomplete.js'
        )
    },
    'tagsinput': {
        'bower': 'bootstrap-tagsinput#0.8.0',
        'css': (
            BC + 'bootstrap-tagsinput/dist/bootstrap-tagsinput.css'
        ),
        'js': (
            BC + 'bootstrap-tagsinput/dist/bootstrap-tagsinput.js')
    },
    'qtip2': {
        'bower': 'qtip2#2.2.1',
        'css': BC + 'qtip2/basic/jquery.qtip.css',
        'js': BC + 'qtip2/basic/jquery.qtip.js'
    },
    'cookie': {
        'bower': 'jquery.cookie#1.4.1',
        'js': BC + 'jquery.cookie/jquery.cookie.js'
    },
    'jquery-ui': {
        'bower': 'jquery-ui#1.12.1',
        'css': BC + 'jquery-ui/themes/ui-lightness/jquery-ui.css',
        'js': [
            BC + 'jquery-ui/jquery-ui.js',
            BC + 'jquery-ui/ui/i18n/datepicker-uk.js',
        ]
    },
    'treeview': {
        'bower': 'bootstrap-treeview#1.2.0',
        'css': (
            BC + 'bootstrap-treeview/'
            'dist/bootstrap-treeview.min.css'
        ),
        'js': (
            BC + 'bootstrap-treeview/'
            'dist/bootstrap-treeview.min.js'
        )
    },
    'slick': {
        'bower': 'slick-carousel#1.8.1',
        'css': [
            BC + 'slick-carousel/slick/slick.css',
            BC + 'slick-carousel/slick/slick-theme.css'
        ],
        'js': BC + 'slick-carousel/slick/slick.js'
    },
    'basement': {
        'css': 'css/indents.css'
    }
}




import os

from django.apps import AppConfig
from django.conf import global_settings

from djassets.constants import STATIC_APPS_MAP


def setup_settings(settings, is_prod, **kwargs):

    base_dir = settings['BASE_DIR']

    extra_static_files = _get_extra_static_files(
        settings.get('STATIC_APPS', []))

    css_components = {
        'generic': {
            'source_filenames': (
                extra_static_files['css'] +
                settings.get('STYLESHEETS', [])
            ),
            'output_filename': 'cache/generic.css',
        }
    }

    if 'CSS_COMPONENTS' in settings:
        for key, filenames in settings.CSS_COMPONENTS.items():
            css_components[key] = {
                'source_filenames': filenames,
                'output_filename': 'cache/{}.css'.format(key),
            }

    js_components = {
        'generic': {
            'source_filenames': (
                extra_static_files['js'] +
                settings.get('JAVASCRIPT', [])
            ),
            'output_filename': 'cache/generic.js',
        }
    }

    if 'JS_COMPONENTS' in settings:
        for key, filenames in settings.JS_COMPONENTS.items():
            js_components[key] = {
                'source_filenames': filenames,
                'output_filename': 'cache/{}.js'.format(key),
            }

    settings.update({
        'STATICFILES_STORAGE': 'pipeline.storage.PipelineManifestStorage',
        'BOWER_INSTALLED_APPS': (
            extra_static_files['bower'] +
            settings.get('BOWER_INSTALLED_APPS', [])
        ),
        'BOWER_COMPONENTS_ROOT': os.path.join(base_dir, 'static'),
        'STATICFILES_DIRS': [
            os.path.join(base_dir, 'static'),
            os.path.join(base_dir, 'static', 'bower_components')
        ],
        'STATICFILES_FINDERS': global_settings.STATICFILES_FINDERS + [
            'pipeline.finders.PipelineFinder',
            'djangobower.finders.BowerFinder'
        ],
        'STATIC_URL': '/static/',
        'MEDIA_URL': '/media/',
        'PIPELINE': {
            'JS_COMPRESSOR': 'pipeline.compressors.jsmin.JSMinCompressor',
            'CSS_COMPRESSOR': 'pipeline.compressors.cssmin.CSSMinCompressor',
            'STYLESHEETS': css_components,
            'JAVASCRIPT': js_components
        },
        'THUMBNAIL_QUALITY': 85,
        'FILE_UPLOAD_PERMISSIONS': 0o755
    })

    settings['MIDDLEWARE'] += [
        'pipeline.middleware.MinifyHTMLMiddleware'
    ]

    extra_apps = [
        'djassets',
        'django.contrib.staticfiles',
        'pipeline',
        'djangobower',
        'django_cleanup',
        'sorl.thumbnail'
    ]

    installed_apps = settings['INSTALLED_APPS']

    for app in extra_apps:
        if app not in installed_apps:
            installed_apps.append(app)

    if is_prod:
        username = settings.get('username', 'dev')
        domain = settings.get('DOMAIN')

        if not domain:
            raise ValueError('Please add `DOMAIN` to settings')

        public_dir = os.path.join(
            'home',  username, 'sites', domain, 'public'
        )

        settings['STATIC_ROOT'] = os.path.join(public_dir, 'static')
        settings['MEDIA_ROOT'] = os.path.join(public_dir, 'media')
    else:
        settings['STATIC_ROOT'] = os.path.join(base_dir, 'static-collect')


def _get_extra_static_files(static_apps):

    components = {
        'bower': [],
        'css': [],
        'js': []
    }

    for app in static_apps:

        app_map = STATIC_APPS_MAP.get(app, {})

        for component in ['bower', 'css', 'js']:
            value = app_map.get(component)

            if value:
                if isinstance(value, str):
                    value = [value]

                components[component] += value

    return components


def _get_static_app_component_list(apps, files_map):

    result = []

    for app in apps:
        try:
            files = files_map[app]
        except KeyError:
            continue

        if isinstance(files, str):
            result.append(files)
        else:
            result += files

    return tuple(result)


class AssetsAppConfig(AppConfig):

    name = 'djassets'


default_app_config = 'djassets.AssetsAppConfig'
